@@ -206,12 +206,9 @@ class MainWindow:
         self.set_tooltips()
         self.setup_tray_icon()
 
-        # Enable/disable the "tags" pane on the right
-        self.annotations_pane = self.builder.get_object('annotations_pane')
-        if self.journal.config.read('showTagsPane') == 1:
-            self.annotations_pane.show()
-        else:
-            self.annotations_pane.hide()
+        # Show/hide the "tags" panel on the right.
+        self.builder.get_object('annotations_pane').set_visible(
+            self.journal.config.read('showTagsPane'))
 
     def set_tooltips(self):
         '''
@@ -377,6 +374,8 @@ class MainWindow:
 
             edit_button.show()
             preview_button.hide()
+
+            self.undo_redo_manager.disable_buttons()
         else:
             # Enter edit mode
             edit_scroll.show()
@@ -385,6 +384,8 @@ class MainWindow:
             preview_button.show()
             edit_button.hide()
 
+            self.undo_redo_manager.update_buttons()
+
         self.template_manager.set_template_menu_sensitive(not preview)
         self.insert_actiongroup.set_sensitive(not preview)
         self.format_actiongroup.set_sensitive(not preview)
