@@ -28,11 +28,12 @@ if not hasattr(builtins, '_'):
 
 program_name = 'RedNotebook'
 tagline = _('A Desktop Journal')
-version = '2.3'
+version = '2.5'
 author = 'Jendrik Seipp'
 author_mail = 'jendrikseipp@gmail.com'
 copyright_ = 'Copyright (c) 2008-2017 Jendrik Seipp'
-url = 'http://rednotebook.sourceforge.net'
+url = 'https://rednotebook.sourceforge.io'
+downloads_url = 'https://rednotebook.sourceforge.io/downloads.html'
 answers_url = 'https://answers.launchpad.net/rednotebook'
 translation_url = 'https://translations.launchpad.net/rednotebook/'
 bug_url = 'https://github.com/jendrikseipp/rednotebook/issues'
@@ -572,7 +573,7 @@ This feature can be used to insert e.g. Latex formulas:
 
 ```
 \'''
-$$\sum_{i=1}^{n} i =\frac{ncdot (n+1)}{2}$$
+$$\\sum_{i=1}^{n} i =\frac{ncdot (n+1)}{2}$$
 \'''
 ```
 
