@@ -229,6 +229,7 @@ def add_header_styles():
         name = 'title%s' % (level)
         styles[name] = style
 
+
 add_header_styles()
 
 # Syntax definition
@@ -298,7 +299,7 @@ hashtag = Pattern(HASHTAG, [(2, 'red'), (3, 'red')])
 
 
 patterns = [
-    get_pattern('\*', 'bold'),
+    get_pattern('\\*', 'bold'),
     get_pattern('_', 'underline'),
     get_pattern('/', 'italic'),
     get_pattern('-', 'strikethrough'),
