@@ -164,6 +164,7 @@ from rednotebook import backup
 
 from rednotebook.util.statistics import Statistics
 from rednotebook.gui.main_window import MainWindow
+from rednotebook import index
 from rednotebook import storage
 from rednotebook.data import Month
 
@@ -186,6 +187,8 @@ class Journal:
         self.date = None
         self.months = {}
 
+        self.search_index = index.Index()
+
         # The dir name is the title
         self.title = ''
 
@@ -294,14 +297,16 @@ class Journal:
 
         try:
             filesystem.make_directory(self.dirs.data_dir)
-        except (OSError, IOError):
+        except (OSError, IOError) as err:
+            logging.error('Creating journal directory failed: {}'.format(err))
             self.frame.show_save_error_dialog(exit_imminent)
             return True
 
         try:
             something_saved = storage.save_months_to_disk(
                 self.months, self.dirs.data_dir, exit_imminent, saveas)
-        except (IOError, OSError):
+        except (IOError, OSError) as err:
+            logging.error('Saving month files failed: {}'.format(err))
             self.frame.show_save_error_dialog(exit_imminent)
             something_saved = None
 
@@ -337,26 +342,30 @@ class Journal:
 
         self.month = None
         self.months.clear()
+        self.frame.search_box.clear()
+        self.search_index.clear()
 
         self.months = storage.load_all_months_from_disk(data_dir)
 
         # Nothing to save before first day change
         self.load_day(self.actual_date)
 
-        self.stats = Statistics(self)
-
-        if self.is_first_start and not os.listdir(data_dir) and len(self.days) == 0:
+        if self.is_first_start and not os.listdir(data_dir) and not self.days:
             self.add_instruction_content()
 
+        # We can't use self.days here since it uses self.save_old_day.
+        for month in self.months.values():
+            for day in month.days.values():
+                self.search_index.add(day.date, day.get_indexed_words())
+
+        self.stats = Statistics(self)
+
         self.frame.cloud.update(force_update=True)
 
-        # Reset Search
-        self.frame.search_box.clear()
-
         self.frame.categories_tree_view.categories = self.categories
         # Add auto-completion for tag search
-        self.frame.search_box.set_entries(['#%s' % self.normalize_tag(tag)
-                                           for tag in self.categories])
+        self.frame.search_box.set_entries(
+            ['#%s' % data.escape_tag(tag) for tag in self.categories])
 
         self.title = filesystem.get_journal_title(data_dir)
 
@@ -391,12 +400,17 @@ class Journal:
 
         return self.months[year_and_month]
 
+    def get_day(self, date):
+        return self.get_month(date).get_day(date.day)
+
     def save_old_day(self):
         '''Order is important'''
+        self.search_index.remove(self.day.date, self.day.get_indexed_words())
         old_content = self.day.content
         new_content = self.frame.categories_tree_view.get_day_content()
         new_content['text'] = self.frame.get_day_text()
         self.day.content = new_content
+        self.search_index.add(self.day.date, self.day.get_indexed_words())
 
         content_changed = (old_content != new_content)
         if content_changed:
@@ -476,9 +490,6 @@ class Journal:
         return list(sorted(set(itertools.chain.from_iterable(
             day.categories for day in self.days)), key=locale.strxfrm))
 
-    def normalize_tag(self, tag):
-        return tag.replace(' ', '_').lower()
-
     def get_entries(self, category):
         entries = set()
         for day in self.days:
@@ -486,10 +497,27 @@ class Journal:
         return sorted(entries)
 
     def search(self, text, tags):
-        days = self.get_days_with_tags(tags)
         results = []
-        for day in reversed(days):
-            results.append(day.search(text, tags))
+        # TODO: Allow using index with a configuration option?
+        use_index = False
+        if use_index:
+            words = data.get_indexed_words(text)
+            words.extend('#{}'.format(tag) for tag in tags)
+
+            if not words:
+                return []
+
+            dates = self.search_index.find(words[0])
+            for word in words[1:]:
+                dates &= self.search_index.find(word)
+
+            for date in sorted(dates, reverse=True):
+                for word in words:
+                    results.append(self.get_day(date).search(word, tags))
+        else:
+            days = self.get_days_with_tags(tags)
+            for day in reversed(days):
+                results.append(day.search(text, tags))
         return results
 
     def get_days_with_tags(self, tags):
@@ -560,6 +588,7 @@ class Journal:
         for example_day in info.example_content:
             self.day.content = example_day
             self.frame.set_date(self.month, self.date, self.day)
+            self.search_index.add(self.day.date, self.day.get_indexed_words())
             self.go_to_next_day()
 
         self.change_date(current_date)
